@@ -5,6 +5,7 @@
 #' Convert vcfR objects to objects supported by other R packages
 #'  
 #' @param x an object of class chromR or vcfR
+#' @param return.alleles should the VCF encoding of the alleles be returned (FALSE) or the actual alleles (TRUE).
 #' 
 #' @details 
 #' After processing vcf data in vcfR, one will likely proceed to an analysis step.
@@ -26,6 +27,10 @@
 #' Because 'forks' do not exist in the windows environment, this will only work for windows users when n.cores=1.
 #' In the Unix environment, users may increase this number to allow the use of multiple threads (i.e., cores).
 #' 
+#' @note \subsection{For users of \pkg{poppr}}{
+#' If you wish to use \code{vcfR2genind()}, it is \strong{strongly recommended} to use it with the option \code{return.alleles = TRUE}.
+#' The reason for this is because the \pkg{poppr} package accomodates mixed-ploidy data by interpreting "0" alleles \emph{in genind objects} to be NULL alleles in both \code{poppr::poppr.amova()} and \code{poppr::locus_table()}.
+#' }
 #' 
 #' 
 #' @seealso
@@ -46,11 +51,18 @@
 #' @aliases vcfR2genind
 #' 
 #' @param sep character (to be used in a regular expression) to delimit the alleles of genotypes
+#' @param ... pass other parameters to adegenet::df2genlight
+#' 
+#' @details 
+#' The parameter \strong{...} is used to pass parameters to other functions.
+#' In \code{vcfR2genind} it is used to pass parameters to \code{adegenet::df2genind}.
+#' For example, setting \code{check.ploidy=FALSE} may improve the performance of \code{adegenet::df2genind}, as long as you know the ploidy.
+#' See \code{?adegenet::df2genind} to see these options.
 #' 
 #' @export
-vcfR2genind <- function(x, sep="[|/]") {
+vcfR2genind <- function(x, sep="[|/]", return.alleles = FALSE, ...) {
   locNames <- x@fix[,'ID']
-  x <- extract.gt(x)
+  x <- extract.gt(x, return.alleles = return.alleles)
   x[grep('.', x, fixed = TRUE)] <- NA
 #  x[grep('\\.', x)] <- NA
 #  x[x == "./."] <- NA
@@ -60,7 +72,7 @@ vcfR2genind <- function(x, sep="[|/]") {
   rownames(x) <- sub(".", "_", rownames(x), fixed = TRUE)
 #  x <- adegenet::df2genind(t(x), sep=sep)
   if( requireNamespace('adegenet') ){
-    x <- adegenet::df2genind(t(x), sep=sep)
+    x <- adegenet::df2genind(t(x), sep=sep, ...)
 #    x <- df2genind(t(x), sep=sep)
   } else {
     warning("adegenet not installed")
@@ -73,13 +85,13 @@ vcfR2genind <- function(x, sep="[|/]") {
 #' @aliases vcfR2loci
 #' 
 #' @export
-vcfR2loci <- function(x)
+vcfR2loci <- function(x, return.alleles = FALSE)
 {
 #  if(class(x) == "chromR")
 #  {
 #    x <- x@vcf
 #  }
-  x <- extract.gt(x)
+  x <- extract.gt(x, return.alleles = return.alleles)
   # modified from pegas::as.loci.genind
   x <- as.data.frame(t(x))
   icol <- 1:ncol(x)
@@ -101,8 +113,20 @@ vcfR2loci <- function(x)
 #' @param n.cores integer specifying the number of cores to use.
 #' 
 #' @examples 
-#' data(vcfR_test)
-#' gl <- vcfR2genlight(vcfR_test)
+#' adegenet_installed <- require("adegenet")
+#' if (adegenet_installed) {
+#'   data(vcfR_test)
+#'   # convert to genlight (preferred method with bi-allelic SNPs)
+#'   gl <- vcfR2genlight(vcfR_test)
+#'   
+#'   # convert to genind, keeping information about allelic state
+#'   # (slightly slower, but preferred method for use with the "poppr" package)
+#'   gid <- vcfR2genind(vcfR_test, return.alleles = TRUE) 
+#'
+#'   # convert to genind, returning allelic states as 0, 1, 2, etc.
+#'   # (not preferred, but slightly faster)
+#'   gid2 <- vcfR2genind(vcfR_test, return.alleles = FALSE)
+#' }
 #' 
 #' @export
 vcfR2genlight <- function(x, n.cores=1){
